==> HostCMS-6.1.7.tar: modules/shop/warehouse/i18n/ru.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS 6\Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2014 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Склады',
	'main_menu_warehouses_list' => "Склады",
	'main_menu_warehouses_add_caption' => "Склад",
	'form_warehouses_add' => "Добавление склада",
	'form_warehouses_edit' => "Редактирование склада",
	'main_menu_warehouses_add' => "Добавить",
	'name' => "<acronym title=\"Текстовое название склада\">Наименование склада</acronym>",
	'sorting' => "<acronym title=\"Порядок сортировки склада\">Порядок сортировки</acronym>",
	'active' => "<acronym title=\"Флаг, определяющий активен ли склад\">Активность склада</acronym>",
	'default' => "<acronym title=\"Флаг, определяющий склад по умолчанию\">Склад \"по умолчанию\"</acronym>",
	'address' => "<acronym title=\"Адрес склада\">Адрес</acronym>",
	'id' => 'Идентификатор',
	'shop_id' => 'Идентификатор магазина',
	'changeStatus_success' => "Информация успешно изменена",
	'changeDefaultStatus_success' => "Информация успешно изменена",
	'edit_success' => "Склад успешно добавлен",
	'default_change_active_error' => "Нельзя убрать статус \"Активен\" у склада \"По умолчанию\"!",
	'apply_success' => "Информация успешно изменена",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'markDeleted_success' => "Информация успешно удалена",
	'warehouse_default_not_exist' => "Внимание! Склад \"по умолчанию\" отсутствует, добавьте склад \"по умолчанию\"!",
	'warehouse_default_name' => "Основной",
	'warehouse_default_count' => "<acronym title=\"Устанавливаем всем товарам количество 0 на данном складе\">Установить количество товара на складе</acronym>",
);

==> HostCMS-6.8.6.tar: modules/shop/warehouse/i18n/ru.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Склады',
	'main_menu_warehouses_list' => "Склады",
	'main_menu_warehouses_add_caption' => "Склад",
	'form_warehouses_add' => "Добавление склада",
	'form_warehouses_edit' => 'Редактирование склада "%s"',
	'main_menu_warehouses_add' => "Добавить",
	'name' => "Наименование склада",
	'sorting' => "Порядок сортировки",
	'active' => "Активность",
	'default' => "Склад \"по умолчанию\"",
	'address' => "Адрес",
	'id' => 'Идентификатор',
	'shop_id' => 'Идентификатор магазина',
	'changeStatus_success' => "Информация успешно изменена",
	'changeDefaultStatus_success' => "Информация успешно изменена",
	'edit_success' => "Склад успешно добавлен",
	'default_change_active_error' => "Нельзя убрать статус \"Активен\" у склада \"По умолчанию\"!",
	'apply_success' => "Информация успешно изменена",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'markDeleted_success' => "Информация успешно удалена",
	'warehouse_default_not_exist' => "Внимание! Склад \"по умолчанию\" отсутствует, добавьте склад \"по умолчанию\"!",
	'warehouse_default_name' => "Основной",
	'warehouse_default_count' => "<acronym title=\"Устанавливаем всем товарам количество 0 на данном складе\">Установить количество товара на складе</acronym>",
	'guid' => 'Идентификатор склада CommerceML',
	'name_other' => 'Альтернативное название',
	'address_info' => 'Дополнительная информация',
	'latitude' => 'Широта',
	'longitude' => 'Долгота',
	'phone' => 'Телефон',
	'website' => 'Сайт',
	'working_time' => 'Часы работы',
	'shop_items_count' => 'Общее количество товаров на складе',
);
